import functools
from datetime import datetime
import pandas as pd

def to_date_time(y: str, m: str, d: str, table: pd.DataFrame) -> datetime:
    """
    Convert year, month, and day columns to a datetime object.

    Args:
        y (str): year
        m (str): month
        d (str): day

    Returns:
        datetime: corresponding datetime set to midnight UTC
    """
    values = table[[y, m, d]].values[0].tolist()
    dtstr = "-".join([str(i).replace(",", "") for i in values])
    return pd.to_datetime(dtstr, format="%Y-%m-%d").tz_localize("UTC").to_pydatetime()


def camel_case_to_display_case(s: str) -> str:
    """
    Convert camel case to display case by introducing a space before each capital letter.

    Args:
        s (str): camel case string

    Returns:
        str: string for display
    """
    result = "".join(" " + char if char.isupper() else char for char in s).strip()
    # Capitalize the first letter of the resulting string
    return result[0].upper() + result[1:] if result else ""


def idempotent(delete_func):
    """
    A decorator to ensure idempotency by deleting an existing item before creating a new one.
    This decorator automatically extracts 'code' and 'scope' parameters from the wrapped function's
    arguments and passes them to the provided delete function.

    Args:
        delete_func (function): The function used to delete an existing item.
    """

    def decorator(create_func):
        @functools.wraps(create_func)
        def wrapper(*args, **kwargs):
            lusid_del_args = ["code", "scope", "domain","source"]
            kwargs_ = {
                k: v for k, v in kwargs.items() if k in lusid_del_args and v is not None
            }
            try:
                delete_func(**kwargs_)
                print(
                    f"Deleted existing item with code: {kwargs_['code']} and scope: {kwargs_['scope']}"
                )
            except Exception as e:
                print(f"No existing item to delete or error deleting item: {e}")

            # Execute the create function
            return create_func(*args, **kwargs)

        return wrapper

    return decorator




from typing import Dict, List
import os as __os

def load()->Dict[str,List[str]]:
    import yaml as __yaml
    dirname = __os.path.dirname(__file__)
    config_path = __os.path.join(dirname, '../config.yaml')
    if not __os.path.exists(config_path):
        return {}
    with open(config_path, 'r') as f:
        return __yaml.safe_load(f) or {}


__all__ = ['load']


from setuptools import setup, find_packages


# List of requirements
requirements = [
    'pyyaml',
'luminesce-sdk-preview==1.14.758',
'lusid-jam==0.1.2',
'lusid-sdk-preview==1.1.420',
'fbnlab-preview==0.1.108',
'finbourne-access-sdk==0.0.3751',
'finbourne-identity-sdk==0.0.2834',
'finbourne-insights-sdk-preview==0.0.763',
'finbourne-sdk-utilities==0.0.10',
'lusid-configuration-sdk-preview==0.1.514',
'lusid-drive-sdk-preview==0.1.617',
'lusid-notifications-sdk-preview==0.1.923',
'lusid-scheduler-sdk-preview==0.0.829',
'lusid-workflow-sdk-preview==0.1.810',
'lusidtools==1.0.14',
'dve-lumipy-preview==0.1.1075',

]




setup(
    name='lusid_express',
    version='1.1.4',
    package_dir={'': 'src'},  # tells setuptools that packages are under src
    packages=find_packages(where='src'),  # tells setuptools to look for packages in src
    install_requires=requirements,
    description='lusid-express is a python package that makes it quick and easy to get started using Lusid and Luminesce.',
    long_description=open('README.md').read(),
    include_package_data=True,  
    long_description_content_type='text/markdown',
    author='Orlando Calvo',
    author_email='orlando.calvo@finbourne.com',
    url='https://gitlab.com/orlando.calvo1/lusid-express',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.9',
    ],
)